package networking

import (
	"os/exec"
	"strings"
)

func GetActiveDevice() (string, error) {

	output, err := exec.Command("networksetup", "-listnetworkserviceorder").Output()

	if err != nil {
		return "", err
	}

	for _, line := range strings.Split(strings.TrimSuffix(string(output), "\n"), "\n") {

		if !strings.Contains(line, "Device:") {
			continue
		}

		//(Hardware Port: Thunderbolt Ethernet Slot 2, Device: en8)
		split := strings.Split(line, ",")
		name := strings.Split(split[0], ":")[1]
		name = strings.TrimPrefix(name, " ")

		device := strings.Split(split[1], ":")[1]
		device = device[1 : len(device)-1]

		active := isDeviceActive(device)

		if active {
			return name, nil
		}

	}

	return "", nil
}

func isDeviceActive(device string) bool {

	output, _ := exec.Command("ifconfig", device).Output()

	for _, line := range strings.Split(strings.TrimSuffix(string(output), "\n"), "\n") {

		if strings.Contains(line, "status: active") {
			return true
		}
	}

	return false
}

func IsProxyEnabled(deviceName string) (bool, error) {
	output, err := exec.Command("networksetup", "-getwebproxy", deviceName).Output()

	if err != nil {
		return false, err
	}

	webEnabled := strings.Contains(string(output), "Enabled: Yes\n")

	output, err = exec.Command("networksetup", "-getsecurewebproxy", deviceName).Output()

	if err != nil {
		return false, err
	}

	secureEnabled := strings.Contains(string(output), "Enabled: Yes\n")

	//todo: if they're not equal, its some sort of error case
	return webEnabled && secureEnabled, nil
}

func SetProxyState(deviceName string, on bool) error {
	onOff := "on"
	if !on {
		onOff = "off"
	}

	err := exec.Command("networksetup", "-setwebproxystate", deviceName, onOff).Run()

	if err != nil {
		return err
	}

	err = exec.Command("networksetup", "-setsecurewebproxystate", deviceName, onOff).Run()

	if err != nil {
		return err
	}

	return nil
}

func SetProxyServer(deviceName string, host string, port string) error {
	err := exec.Command("networksetup", "-setwebproxy", deviceName, host, port).Run()
	if err != nil {
		return err
	}
	err = exec.Command("networksetup", "-setsecurewebproxy", deviceName, host, port).Run()
	if err != nil {
		return err
	}

	return nil
}
